package tallerVehiculos;

import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.util.ArrayList;

import javax.swing.JOptionPane;

@SuppressWarnings("serial")
public class GestionVehiculos implements Serializable{
	
	private ArrayList<Vehiculo> vehiculos;
	
	public GestionVehiculos() {
		vehiculos = new ArrayList<Vehiculo>();
	}
	
	public boolean nuevoVehiculo(Vehiculo v) {
		if (vehiculos.contains(v)) {
			JOptionPane.showMessageDialog(null, "Ya existe un Vehículo con VIN: " + v.getVIN(),
					"Nuevo Vehículo", JOptionPane.WARNING_MESSAGE);
			return false;
		}
		else {
			vehiculos.add(v);
			return true;
		}
	}
	
	public Vehiculo buscarVehiculo(String dato) {
		for (Vehiculo v: vehiculos) {
			if (v.getVIN().equals(dato) || v.getPlaca().equals(dato))
				return v;
		}
		
		return null;
	}
	
	public void eliminarVehiculo(Vehiculo v) {
		vehiculos.remove(v);
	}
	
	
	public boolean guardarVehiculos() {
		try {
			ObjectOutputStream obs = new ObjectOutputStream(new FileOutputStream("vehiculos.bin"));
			obs.writeObject(this);
			obs.close();
			return true;
		} catch (IOException e) {
			JOptionPane.showMessageDialog(null, "Error al acceder al archivo: vehiculos.bin",
					"Guardar Vehículos", JOptionPane.ERROR_MESSAGE);
			e.printStackTrace();
			return false;
		}
	}
	
	public String[][] listaVehiculosMantenimiento() {
		/*
		 * Vehiculos en mantenimiento son los que tiene una 
		 * fecha de INICIO de reparación, pero no de FINALIZACIÓN.
		 */
		//Creamos un ArrayList con SOLO los vehiculos en mantenimiento.
		ArrayList<Vehiculo> mantenimiento = new ArrayList<Vehiculo>();
		for (Vehiculo v: vehiculos)
			if (!v.getFechaInicio().equals("No Iniciado") &&
					v.getFechaTermino().equals("No Terminado"))
				mantenimiento.add(v);
		/*
		 * Con esta selección, creamos una matriz con los atributos que queremos
		 *  mostrar en los informes. En mi caso voy a querer mostrar 6 atributos:
		 *  TipoVehiculo | Placa | VIN | Marca | Modelo | Fecha Inicio
		 */
		String[][] informe = new String[mantenimiento.size()][6];
		for (int i = 0; i < mantenimiento.size(); i++) {
			informe[i][0] = (mantenimiento.get(i) instanceof Diesel)?"Diesel":"Gasolina";
			informe[i][1] = mantenimiento.get(i).getPlaca();
			informe[i][2] = mantenimiento.get(i).getVIN();
			informe[i][3] = mantenimiento.get(i).getMarca();
			informe[i][4] = mantenimiento.get(i).getModelo();
			informe[i][5] = mantenimiento.get(i).getFechaInicio();
		}
		
		return informe;
	}
	
	public String[][] listaVehiculosEntregados() {
		
		//Creamos un ArrayList con SOLO los vehiculos ENTREGADOS.
		ArrayList<Vehiculo> mantenimiento = new ArrayList<Vehiculo>();
		for (Vehiculo v: vehiculos)
			if (v.isEntregado())
				mantenimiento.add(v);
		/*
		 * Con esta selección, creamos una matriz con los atributos que queremos
		 *  mostrar en los informes. En mi caso voy a querer mostrar 6 atributos:
		 *  TipoVehiculo | Placa | VIN | Marca | Modelo | Fecha Termino
		 */
		String[][] informe = new String[mantenimiento.size()][6];
		for (int i = 0; i < mantenimiento.size(); i++) {
			informe[i][0] = (mantenimiento.get(i) instanceof Diesel)?"Diesel":"Gasolina";
			informe[i][1] = mantenimiento.get(i).getPlaca();
			informe[i][2] = mantenimiento.get(i).getVIN();
			informe[i][3] = mantenimiento.get(i).getMarca();
			informe[i][4] = mantenimiento.get(i).getModelo();
			informe[i][5] = mantenimiento.get(i).getFechaTermino();
		}
		
		return informe;
	}

}
